@@ -8,13 +8,15 @@
 #
 package Net::Gandi::Hosting::IP;
 {
-  $Net::Gandi::Hosting::IP::VERSION = '1.121851';
+  $Net::Gandi::Hosting::IP::VERSION = '1.122080';
 }
 
 # ABSTRACT: Ip interface
 
 use Moose;
 use MooseX::Params::Validate;
+use namespace::autoclean;
+
 use Net::Gandi::Types Client => { -as => 'Client_T' };
 use Net::Gandi::Error qw(_validated_params);
 
@@ -37,7 +39,7 @@ sub list {
     );
 
     $params ||= {};
-    return $self->client->call_rpc( 'ip.list', $params );
+    return $self->client->api_call( 'ip.list', $params );
 }
 
 
@@ -48,7 +50,7 @@ sub count {
     );
 
     $params ||= {};
-    return $self->client->call_rpc('ip.count', $params);
+    return $self->client->api_call('ip.count', $params);
 }
 
 
@@ -56,7 +58,7 @@ sub info {
     my ( $self ) = @_;
 
     carp 'Required parameter id is not defined' if ( ! $self->id );
-    return $self->client->call_rpc( 'ip.info', $self->id );
+    return $self->client->api_call( 'ip.info', $self->id );
 }
 
 
@@ -70,22 +72,24 @@ sub update {
     _validated_params('ip_update', $params);
 
     $params ||= {};
-    return $self->client->call_rpc('ip.update', $self->id, $params);
+    return $self->client->api_call('ip.update', $self->id, $params);
 }
 
 #sub attach {
 #    my ( $self, $iface_id ) = @_;
 #
-#    return $self->client->call_rpc('iface.attach', $iface_id, $self->id);
+#    return $self->client->api_call('iface.attach', $iface_id, $self->id);
 #}
 
 
 #sub detach {
 #    my ( $self, $iface_id ) = @_;
 #
-#    return $self->client->call_rpc('iface.detach', $iface_id, $self->id);
+#    return $self->client->api_call('iface.detach', $iface_id, $self->id);
 #}
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -98,7 +102,7 @@ Net::Gandi::Hosting::IP - Ip interface
 
 =head1 VERSION
 
-version 1.121851
+version 1.122080
 
 =head1 ATTRIBUTES
 
