@@ -8,12 +8,14 @@
 #
 package Net::Gandi::Operation;
 {
-  $Net::Gandi::Operation::VERSION = '1.121851';
+  $Net::Gandi::Operation::VERSION = '1.122080';
 }
 
 # ABSTRACT: Operation interface
 
 use Moose;
+use namespace::autoclean;
+
 use Net::Gandi::Types Client => { -as => 'Client_T' };
 
 use Carp;
@@ -32,11 +34,13 @@ sub info {
     my ( $self ) = @_;
 
     carp 'Required parameter id is not defined' if ( ! $self->id );
-    return $self->client->call_rpc( 'operation.info', $self->id );
+    return $self->client->api_call( 'operation.info', $self->id );
 }
 
-1;
+no Moose;
+__PACKAGE__->meta->make_immutable;
 
+1;
 
 __END__
 =pod
@@ -47,7 +51,7 @@ Net::Gandi::Operation - Operation interface
 
 =head1 VERSION
 
-version 1.121851
+version 1.122080
 
 =head1 METHODS
 
